@@ -18,11 +18,11 @@
 # -- Project information -----------------------------------------------------
 
 project = 'Consfigurator'
-copyright = '2020-2022, Sean Whitton'
+copyright = '2015-2018, 2020-2023, Sean Whitton, 2021-2022 David Bremner'
 author = 'Sean Whitton'
 
 # The full version, including alpha/beta/rc tags
-release = '1.2.3'
+release = '1.3.1'
 
 
 # -- General configuration ---------------------------------------------------
@@ -54,7 +54,7 @@ html_theme = 'sphinx_rtd_theme'
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
-html_static_path = ['_static']
+# html_static_path = ['_static']
 
 
 # -- Options for Texinfo output ----------------------------------------------
