@@ -16,6 +16,7 @@
                           #:slurp-stream-string
                           #:subprocess-error
                           #:stripln
+                          #:println
                           #:unix-namestring
                           #:parse-unix-namestring
                           #:pathname-directory-pathname
@@ -45,6 +46,7 @@
                           #:safe-read-from-string
                           #:compile-file*
                           #:compile-file-pathname*)
+  (:shadowing-import-from #:parse-number #:parse-number)
   (:export ;; re-export from UIOP
            #:strcat
            #:string-prefix-p
@@ -58,6 +60,7 @@
            #:slurp-stream-string
            #:subprocess-error
            #:stripln
+           #:println
            #:unix-namestring
            #:parse-unix-namestring
            #:pathname-directory-pathname
@@ -88,6 +91,9 @@
            #:compile-file*
            #:compile-file-pathname*
 
+           ;; re-export from PARSE-NUMBER
+           #:parse-number
+
            ;; libc.lisp
            #:uid_t
            #:gid_t
@@ -256,6 +262,7 @@
            #:silent-seqprops
            #:unapply
            #:unapplied
+           #:reapplied
            #:desc
            #:on-change
            #:on-apply-change
@@ -489,7 +496,8 @@
 
   (package :consfigurator.property.periodic
            (:local-nicknames (#:file  #:consfigurator.property.file))
-           (:export #:at-most))
+           (:export #:at-most
+                    #:reapplied-at-most))
 
   (package :consfigurator.property.mount
            (:local-nicknames (#:os    #:consfigurator.property.os)
