@@ -13,7 +13,7 @@
 ;;; GNU General Public License for more details.
 
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
+;;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 (in-package :consfigurator.property.apt)
 (named-readtables:in-readtable :consfigurator)
@@ -209,12 +209,12 @@ packages.  Does not do any automatic upgrades."
   (:desc "apt periodic updates")
   (:hostattrs (os:required 'os:debianlike))
   (:apply
-   (file:has-content "/etc/apt/apt.conf.d/02periodic"
-#>EOF>APT::Periodic::Enable "1";
-APT::Periodic::Update-Package-Lists "1";
-APT::Periodic::Download-Upgradeable-Packages "1";
-APT::Periodic::Verbose "1";
-EOF))
+   (file:has-content "/etc/apt/apt.conf.d/02periodic" #>>~EOF>>
+                     APT::Periodic::Enable "1";
+                     APT::Periodic::Update-Package-Lists "1";
+                     APT::Periodic::Download-Upgradeable-Packages "1";
+                     APT::Periodic::Verbose "1";
+                     EOF))
   (:unapply
    (file:does-not-exist "/etc/apt/apt.conf.d/02periodic")))
 
