@@ -13,7 +13,7 @@
 ;;; GNU General Public License for more details.
 
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
+;;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 (in-package :consfigurator.property.chroot)
 (named-readtables:in-readtable :consfigurator)
@@ -100,7 +100,7 @@
                              ,(propspec-props propspec))))))
 
 (defproplist deploys :lisp (root host &optional additional-properties)
-  "Like DEPLOYS with first argument `((:chroot :into ,root)), but disable
+  "Like DEPLOYS with first argument ```((:chroot :into ,root))``, but disable
 starting services in the chroot, and set up access to parent hostattrs."
   (:desc #?"Subdeployment of ${root}")
   (consfigurator:deploys
@@ -108,8 +108,9 @@ starting services in the chroot, and set up access to parent hostattrs."
    (%make-child-host (union-propspec-into-host host additional-properties))))
 
 (defproplist deploys-these :lisp (root host properties)
-  "Like DEPLOYS-THESE with first argument `((:chroot :into ,root)), but disable
-starting services in the chroot, and set up access to parent hostattrs."
+  "Like DEPLOYS-THESE with first argument ```((:chroot :into ,root))``, but
+disable starting services in the chroot, and set up access to parent
+hostattrs."
   (:desc #?"Subdeployment of ${root}")
   (consfigurator:deploys
    `((:chroot :into ,root))
