@@ -13,7 +13,7 @@
 ;;; GNU General Public License for more details.
 
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
+;;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 (in-package :consfigurator.property.disk)
 (named-readtables:in-readtable :consfigurator)
@@ -998,7 +998,7 @@ filesystems will be incrementally updated when other properties change."
     (options host device-file &key chroot)
   "Install HOST to the DISK:PHYSICAL-DISK accessible at DEVICE-FILE.
 **THIS PROPERTY UNCONDITIONALLY FORMATS DISKS, POTENTIALLY DESTROYING DATA,
-  EACH TIME IT IS APPLIED.**
+EACH TIME IT IS APPLIED.**
 
 Do not apply in DEFHOST.  Apply with DEPLOY-THESE/HOSTDEPLOY-THESE.
 
@@ -1024,7 +1024,8 @@ least the following:
 If CHROOT, an intermediate chroot is bootstrapped at CHROOT, and HOST's
 properties are applied to that.  Otherwise, HOST's OS is bootstrapped directly
 to DEVICE-FILE.  It's useful to supply CHROOT when you expect to install the
-same HOST to a number of physical disks.
+same HOST to a number of physical disks.  It also makes it faster to try
+deploying again if failures occur during the application of HOST's properties.
 
 Applying this property is similar to applying DISK:RAW-IMAGE-BUILT-FOR and
 then immediately dd'ing out the image to DEVICE-FILE.  The advantage of this
@@ -1046,7 +1047,7 @@ the host's actual physical disk upon first boot."
 (defpropspec volumes-installed-for :lisp (options host &key chroot leave-open)
   "Install HOST to its volumes, as specified using DISK:HAS-VOLUMES.
 **THIS PROPERTY UNCONDITIONALLY FORMATS DISKS, POTENTIALLY DESTROYING DATA,
-  EACH TIME IT IS APPLIED.**
+EACH TIME IT IS APPLIED.**
 
 Do not apply in DEFHOST.  Apply with DEPLOY-THESE/HOSTDEPLOY-THESE.
 
@@ -1206,16 +1207,14 @@ Currently only handling of LVM logical volumes is implemented."
 
 (defun parse-volume-size (volume-size-specification)
   (if (stringp volume-size-specification)
-      (multiple-value-bind (match groups)
-          (re:scan-to-strings #?/\A([0-9]+)([MGT])?\z/ volume-size-specification)
-        (unless match
-          (simple-program-error
-           "~A is not a valid volume size." volume-size-specification))
-        (* (parse-integer (elt groups 0))
-           (eswitch ((elt groups 1) :test #'string=)
-             ("M" 1)
-             ("G" 1024)
-             ("T" 1048576))))
+      (aif (#~/\A(\d+)([MGT])?\z/p volume-size-specification)
+           (* (elt it 0)
+              (eswitch ((elt it 1) :test #'string=)
+                ("M" 1)
+                ("G" 1024)
+                ("T" 1048576)))
+           (simple-program-error "~A is not a valid volume size."
+                                 volume-size-specification))
       volume-size-specification))
 
 (defmacro volumes (&body volume-specifications)
@@ -1233,28 +1232,28 @@ specifications.  This becomes the VOLUME-CONTENTS of the VOLUME.
 
 The following keys in INITARGS are handled specially:
 
-    - :VOLUME-SIZE -- may be a string like \"100M\", \"2G\", \"1T\" which will
-      be converted into a whole number of mebibytes.  \"M\", \"G\", and \"T\"
-      are currently supported.
+  - :VOLUME-SIZE -- may be a string like \"100M\", \"2G\", \"1T\" which will
+    be converted into a whole number of mebibytes.  \"M\", \"G\", and \"T\"
+    are currently supported.
 
 Example usage:
 
-  (volumes
-    (physical-disk
-     (partitioned-volume
-      ((partition
-        :partition-typecode #xef00
-        (fat32-filesystem
-         :volume-size \"512M\"
-         :mount-point #P\"/boot/efi\"))
-       (partition
-        (luks-container
-         (lvm-physical-volume
-          :volume-group \"vg_laptop\"))))))
-    (lvm-logical-volume
-       :volume-group \"vg_laptop\"
-       :volume-label \"lv_laptop_root\"
-       (ext4-filesystem :mount-point #P\"/\")))"
+    (volumes
+      (physical-disk
+       (partitioned-volume
+        ((partition
+          :partition-typecode #xef00
+          (fat32-filesystem
+           :volume-size \"512M\"
+           :mount-point #P\"/boot/efi\"))
+         (partition
+          (luks-container
+           (lvm-physical-volume
+            :volume-group \"vg_laptop\"))))))
+      (lvm-logical-volume
+         :volume-group \"vg_laptop\"
+         :volume-label \"lv_laptop_root\"
+         (ext4-filesystem :mount-point #P\"/\")))"
   (labels
       ((parse (spec)
          (unless (listp spec)
