@@ -13,7 +13,7 @@
 ;;; GNU General Public License for more details.
 
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
+;;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 (in-package :consfigurator.property.sbuild)
 (named-readtables:in-readtable :consfigurator)
@@ -76,13 +76,12 @@ Example usage:
     (apt:mirrors \"...\")
     (sbuild:usable-by \"spwhitton\")
     (schroot:overlays-in-tmpfs)
-    (periodic:at-most :monthly \"sbuild sid schroot rebuilt\"
-      (unapplied (sbuild:built. nil (os:debian-unstable :amd64))))
-    (sbuild:built. nil
-      (os:debian-unstable :amd64)
-      (sbuild:standard-debian-schroot)
-      (apt:uses-parent-proxy)
-      (apt:uses-parent-mirrors))
+    (periodic:reapplied-at-most :monthly \"sbuild sid schroot (re)built\"
+      (sbuild:built. nil
+        (os:debian-unstable :amd64)
+        (sbuild:standard-debian-schroot)
+        (apt:uses-parent-proxy)
+        (apt:uses-parent-mirrors)))
 
 To take advantage of the piuparts and autopkgtest support, add to your
 ~/.sbuildrc:
@@ -123,17 +122,17 @@ To take advantage of the piuparts and autopkgtest support, add to your
         (file:contains-lines "/etc/schroot/sbuild/fstab"
           "/var/cache/ccache-sbuild /var/cache/ccache-sbuild none rw,bind 0 0"))
        ;; Script from <https://wiki.debian.org/sbuild>.
-       (file:has-content "/var/cache/ccache-sbuild/sbuild-setup"
-#>EOF>#!/bin/sh
+       (file:has-content "/var/cache/ccache-sbuild/sbuild-setup" #>>~EOF>>
+                         #!/bin/sh
 
-export CCACHE_DIR=/var/cache/ccache-sbuild
-export CCACHE_UMASK=002
-export CCACHE_COMPRESS=1
-unset CCACHE_HARDLINK
-export PATH="/usr/lib/ccache:$PATH"
+                         export CCACHE_DIR=/var/cache/ccache-sbuild
+                         export CCACHE_UMASK=002
+                         export CCACHE_COMPRESS=1
+                         unset CCACHE_HARDLINK
+                         export PATH="/usr/lib/ccache:$PATH"
 
-exec "$@"
-EOF :mode #o755)
+                         exec "$@"
+                         EOF :mode #o755)
 
        ;; schroot
        (chroot:os-bootstrapped-for ,chroot-options ,chroot ,host)
